@@ -1,14 +1,13 @@
 package                                # Hide from PAUSE.
   WiX3::Trace::Object;
 
-use 5.008001;
+use 5.008003;
 use MooseX::Singleton;
 use WiX3::Util::StrictConstructor;
 use WiX3::Types qw( Tracelevel );
 use MooseX::Types::Moose qw( Bool );
 
-our $VERSION = '0.009';
-$VERSION =~ s/_//ms;
+our $VERSION = '0.011';
 
 has tracelevel => (
 	is      => 'rw',
@@ -29,12 +28,16 @@ sub trace_line {
 	my $self = shift;
 	my ( $level, $text ) = @_;
 
-	if ( $level <= $self->get_tracelevel() ) {
+	# We hit this routine so many times that it accumulates
+	# a minute's worth of time when building Strawberry 5.12.0
+	# 64-bit. (profiling by NYTProf)
+	# I would not normally break encapsulation like this.
+	if ( $level <= $self->{tracelevel} ) {
 		print $text;
 	}
 
 	return $text;
-}
+} ## end sub trace_line
 
 no MooseX::Singleton;
 __PACKAGE__->meta->make_immutable( inline_constructor => 0 );
