@@ -1,22 +1,25 @@
 package WiX3::XML::CreateFolder;
 
-use 5.008001;
+use 5.008003;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose;
+use Moose 2;
 use Params::Util qw( _STRING  );
+use WiX3::XML::TagTypes qw( ShortcutTag );
+use MooseX::Types::Moose qw( Str Maybe ArrayRef );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.009';
-$VERSION =~ s/_//ms;
+our $VERSION = '0.011';
 
 with 'WiX3::XML::Role::TagAllowsChildTags';
 ## Allows Permission, PermissionEx, Shortcut as children.
 
+has '+child_tags' => ( isa => ArrayRef [ShortcutTag] );
+
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_createfolder.htm
 
 #####################################################################
@@ -74,7 +77,7 @@ WiX3::XML::CreateFolder - Defines a CreateFolder tag.
 
 =head1 VERSION
 
-This document describes WiX3::XML::CreateFolder version 0.009
+This document describes WiX3::XML::CreateFolder version 0.009100
 
 =head1 SYNOPSIS
 
