@@ -7,21 +7,20 @@ package WiX3::XML::Environment;
 #
 # License is the same as perl. See WiX3.pm for details.
 #
-use 5.008001;
+use 5.008003;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose;
+use Moose 2;
 use Params::Util qw( _IDENTIFIER _STRING );
-use WiX3::Types qw( YesNoType );
+use WiX3::Types qw( YesNoType EnumEnvironmentAction);
 use MooseX::Types::Moose qw( Str Maybe );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.009';
-$VERSION =~ s/_//ms;
+our $VERSION = '0.011';
 
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_environment.htm
 
@@ -58,7 +57,7 @@ has value => (
 
 has action => (
 	is      => 'ro',
-	isa     => Str,
+	isa     => EnumEnvironmentAction,
 	reader  => '_get_action',
 	default => 'set',
 );
