@@ -1,20 +1,20 @@
 package WiX3::XML::Feature;
 
-use 5.008001;
+use 5.008003;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose;
+use Moose 2;
 use Params::Util qw( _IDENTIFIER _STRING );
 use WiX3::Types qw( YesNoType );
-use MooseX::Types::Moose qw( Str Int Maybe );
+use MooseX::Types::Moose qw( Str Int Maybe ArrayRef );
+use WiX3::XML::TagTypes qw( FeatureChildTag );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.009';
-$VERSION =~ s/_//ms;
+our $VERSION = '0.011';
 
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_feature.htm
 
@@ -24,6 +24,11 @@ with 'WiX3::XML::Role::TagAllowsChildTags';
 # Component, ComponentGroupRef, ComponentRef, Condition, Feature,
 # FeatureGroupRef, FeatureRef, MergeRef
 
+## FeatureChildTag allows Component, ComponentRef, Feature, FeatureRef,
+## and MergeRef at the moment.
+
+has '+child_tags' => ( isa => ArrayRef [FeatureChildTag] );
+
 #####################################################################
 # Accessors:
 #   see new.
@@ -170,7 +175,7 @@ WiX3::XML::Feature - Defines a Feature tag.
 
 =head1 VERSION
 
-This document describes WiX3::XML::Feature version 0.009
+This document describes WiX3::XML::Feature version 0.009100
 
 =head1 SYNOPSIS
 
