@@ -1,19 +1,19 @@
 package WiX3::XML::File;
 
-use 5.008001;
+use 5.008003;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose;
+use Moose 2;
 use WiX3::Types qw( YesNoType PositiveInt NonNegativeInt );
-use MooseX::Types::Moose qw( Str Maybe Int );
+use WiX3::XML::TagTypes qw( ShortcutTag );
+use MooseX::Types::Moose qw( Str Maybe Int ArrayRef );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.009';
-$VERSION =~ s/_//ms;
+our $VERSION = '0.011';
 
 with 'WiX3::XML::Role::TagAllowsChildTags';
 
@@ -23,12 +23,15 @@ with 'WiX3::XML::Role::TagAllowsChildTags';
 # ODBCDriver, ODBCTranslator, Permission, PermissionEx, Shortcut, SymbolPath,
 # TypeLib
 
+has '+child_tags' => ( isa => ArrayRef [ShortcutTag] );
+
+
 #####################################################################
 # Attributes:
 
 has _assembly => (
 	is       => 'ro',
-	isa      => Str,                   # '.net', 'no', or 'win32'
+	isa      => Maybe [Str],           # '.net', 'no', or 'win32'
 	reader   => '_get_assembly',
 	init_arg => 'assembly',
 	default  => undef,
@@ -36,7 +39,7 @@ has _assembly => (
 
 has _assemblyapplication => (
 	is       => 'ro',
-	isa      => Str,
+	isa      => Maybe [Str],
 	reader   => '_get_assemblyapplication',
 	init_arg => 'assemblyapplication',
 	default  => undef,
@@ -44,7 +47,7 @@ has _assemblyapplication => (
 
 has _assemblymanifest => (
 	is       => 'ro',
-	isa      => Str,
+	isa      => Maybe [Str],
 	reader   => '_get_assemblymanifest',
 	init_arg => 'assemblymanifest',
 	default  => undef,
@@ -52,7 +55,7 @@ has _assemblymanifest => (
 
 has _bindpath => (
 	is       => 'ro',
-	isa      => Str,
+	isa      => Maybe [Str],
 	reader   => '_get_bindpath',
 	init_arg => 'bindpath',
 	default  => undef,
@@ -147,7 +150,7 @@ has _keypath => (
 
 has name => (
 	is      => 'ro',
-	isa     => Str,                    # LongNameFileType
+	isa     => Maybe [Str],            # LongNameFileType
 	reader  => 'get_name',
 	default => undef,
 );
@@ -186,7 +189,7 @@ has _patchgroup => (
 
 has _processorarchitecture => (
 	is     => 'ro',
-	isa    => Str,                     # 'msil', 'x86', 'x64', or 'ia64'
+	isa    => Maybe [Str],             # 'msil', 'x86', 'x64', or 'ia64'
 	reader => '_get_processorarchitecture',
 	init_arg => 'processorarchitecture',
 	default  => undef,
@@ -202,7 +205,7 @@ has _readonly => (
 
 has _selfregcost => (
 	is       => 'ro',
-	isa      => 'Int',
+	isa      => Maybe [Int],
 	reader   => '_get_selfregcost',
 	init_arg => 'selfregcost',
 	default  => undef,
@@ -210,7 +213,7 @@ has _selfregcost => (
 
 has _shortname => (
 	is       => 'ro',
-	isa      => 'Str',                 # ShortFileNameType
+	isa      => Maybe [Str],           # ShortFileNameType
 	reader   => '_get_shortname',
 	init_arg => 'shortname',
 	default  => undef,
@@ -218,7 +221,7 @@ has _shortname => (
 
 has _source => (
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Maybe [Str],
 	reader   => '_get_source',
 	init_arg => 'source',
 	default  => undef,
@@ -330,7 +333,7 @@ WiX3::XML::File - TODO.
 
 =head1 VERSION
 
-This document describes WiX3::XML::File version 0.009
+This document describes WiX3::XML::File version 0.009100
 
 =head1 SYNOPSIS
 
